"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.appDayBundle = void 0;

var _reduxBundler = require("redux-bundler");

var _date = require("../utils/date");

const DAY_UPDATED = 'DAY_UPDATED';
const appDayBundle = {
  name: 'appDay',
  init: store => {
    // check at least every 10 minutes
    const maxInterval = 1000 * 60 * 10;

    const updateIfDifferent = () => {
      const startOfToday = (0, _date.getStartOfDate)();

      if (store.selectAppDayRaw() !== startOfToday.valueOf()) {
        store.dispatch({
          type: DAY_UPDATED,
          payload: startOfToday.valueOf()
        });
      }
    };

    const scheduleDayCheck = () => {
      updateIfDifferent();
      const now = new Date();
      const tomorrowStart = new Date(now.getFullYear(), now.getMonth(), now.getDate() + 1, 0, 0, 0);
      const diff = tomorrowStart.valueOf() - now.valueOf();
      setTimeout(scheduleDayCheck, Math.min(diff, maxInterval));
    };

    scheduleDayCheck();
  },
  reducer: (state = (0, _date.getStartOfDate)().valueOf(), {
    type,
    payload
  }) => {
    if (type === DAY_UPDATED) {
      return payload;
    }

    return state;
  },
  selectAppDayRaw: state => state.appDay,
  selectAppDayDate: (0, _reduxBundler.createSelector)('selectAppDayRaw', dateInMs => new Date(dateInMs))
};
exports.appDayBundle = appDayBundle;